<?php
// Get current settings
$settings = get_option('loan_calculator_settings', [
  'MIN_AMOUNT' => 30000,
  'MAX_AMOUNT' => 30000000,
  'INTEREST_RATE' => 0.1,
  'max_term' => 15,
  'PRESET_AMOUNTS' => "300000,1000000",
  'terms_link' => '',
  'products_link' => '',
  'currency_symbol' => '₽'
]);
?>

<div class="wrap">
  <h1><?php _e('Loan Calculator Settings', 'loan-calculator'); ?></h1>
  <form method="post" action="options.php">
    <?php
    settings_fields('loan_calculator_options');
    do_settings_sections('loan_calculator_options');
    ?>

    <table class="form-table">
      <tr>
        <th scope="row"><?php _e('Minimum Loan Amount', 'loan-calculator'); ?></th>
        <td>
          <input type="number" name="loan_calculator_settings[MIN_AMOUNT]"
            value="<?php echo esc_attr($settings['MIN_AMOUNT']); ?>" />
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Maximum Loan Amount', 'loan-calculator'); ?></th>
        <td>
          <input type="number" name="loan_calculator_settings[MAX_AMOUNT]"
            value="<?php echo esc_attr($settings['MAX_AMOUNT']); ?>" />
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Interest Rate (%)', 'loan-calculator'); ?></th>
        <td>
          <input type="number" step="0.1" name="loan_calculator_settings[INTEREST_RATE]"
            value="<?php echo esc_attr($settings['INTEREST_RATE']); ?>" />
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Maximum Loan Term (years)', 'loan-calculator'); ?></th>
        <td>
          <input type="number" name="loan_calculator_settings[max_term]"
            value="<?php echo esc_attr($settings['max_term']); ?>" />
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Preset Loan Amounts', 'loan-calculator'); ?></th>
        <td>
          <input type="text" name="loan_calculator_settings[PRESET_AMOUNTS]"
            value="<?php echo esc_attr($settings['PRESET_AMOUNTS']); ?>"
            placeholder="100000, 1000000" />
          <p class="description"><?php _e('Enter amounts separated by commas', 'loan-calculator'); ?></p>
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Terms and Conditions Link', 'loan-calculator'); ?></th>
        <td>
          <input type="url" name="loan_calculator_settings[terms_link]"
            value="<?php echo esc_attr($settings['terms_link']); ?>"
            placeholder="https://example.com/terms"
            class="regular-text" />
          <p class="description"><?php _e('Full link to the information transfer terms page', 'loan-calculator'); ?></p>
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Products Link', 'loan-calculator'); ?></th>
        <td>
          <input type="url" name="loan_calculator_settings[products_link]"
            value="<?php echo esc_attr($settings['products_link']); ?>"
            placeholder="https://example.com/products"
            class="regular-text" />
          <p class="description"><?php _e('Full link to the products and services information page', 'loan-calculator'); ?></p>
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Currency Symbol', 'loan-calculator'); ?></th>
        <td>
          <input type="text" name="loan_calculator_settings[currency_symbol]"
            value="<?php echo esc_attr($settings['currency_symbol'] ?? '₽'); ?>"
            placeholder="₽"
            class="regular-text" />
          <p class="description"><?php _e('Currency symbol to display (default: ₽)', 'loan-calculator'); ?></p>
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Phone Mask', 'loan-calculator'); ?></th>
        <td>
          <input type="text" name="loan_calculator_settings[phone_mask]"
            value="<?php echo esc_attr($settings['phone_mask'] ?? '+7 (###) ###-##-##'); ?>"
            placeholder="+7 (###) ###-##-##"
            class="regular-text" />
          <p class="description"><?php _e('Phone input mask (use # for digits, default: +7 (###) ###-##-##)', 'loan-calculator'); ?></p>
        </td>
      </tr>
      <tr>
        <th scope="row"><?php _e('Required Full Name Words', 'loan-calculator'); ?></th>
        <td>
          <input type="number" name="loan_calculator_settings[required_name_words]"
            value="<?php echo esc_attr($settings['required_name_words'] ?? 3); ?>"
            min="1" max="10"
            class="small-text" />
          <p class="description"><?php _e('Number of required words for full name field (default: 3)', 'loan-calculator'); ?></p>
        </td>
      </tr>
    </table>

    <?php submit_button(); ?>
  </form>
</div>
