<?php
$settings = get_option('loan_calculator_settings', [
  'terms_link' => '',
  'products_link' => '',
  'currency_symbol' => '₽',
  'phone_mask' => '+7 (___) ___-__-__'
]);
?>

<div id="app" class="credit-calculator-app">
  <div class="container">
    <div class="main-card">
      <h2><?php _e('Loan Calculator', 'loan-calculator'); ?></h2>

      <div class="input-group">
        <label><?php _e('Desired Loan Amount', 'loan-calculator'); ?></label>
        <div class="amount-input">
          <input
            type="text"
            :value="formattedAmount + ' <?php echo esc_js($settings['currency_symbol']); ?>'"
            @focus="handleAmountFocus"
            @blur="handleAmountBlur" />
        </div>
        <input
          type="range"
          v-model="sliderValue"
          :min="0"
          :max="100"
          :step="0.01"
          @input="calculateMonthlyPayment" />
        <div class="range-labels">
          <button
            v-for="(amount, index) in PRESET_AMOUNTS"
            :key="amount"
            @click="setAmount(amount)"
            :class="{ 'hide-mobile': index !== 0 && index !== PRESET_AMOUNTS.length - 1 }"
            type="button">
            {{ formatNumber(amount) }} <?php echo esc_js($settings['currency_symbol']); ?>
          </button>
        </div>
      </div>

      <div class="input-group term-range-group">
        <label><?php _e('Loan Term', 'loan-calculator'); ?></label>
        <div class="term-input">
          <input
            type="text"
            :value="formattedTerm + ' ' + getYearDeclension(term)"
            @blur="handleTermBlur"
            @focus="handleTermFocus" />
        </div>
        <input
          type="range"
          v-model.number="term"
          :min="1"
          :max="MAX_TERM"
          @input="calculateMonthlyPayment" />
        <div class="range-labels term-labels">
          <span>1 <?php _e('year', 'loan-calculator'); ?></span>
          <span>{{MAX_TERM}} {{ getYearDeclension(MAX_TERM) }}</span>
        </div>
      </div>

      <div class="input-group">
        <label><?php _e('Monthly Payment', 'loan-calculator'); ?></label>
        <div class="payment-display">
          <span>{{ formatNumber(monthlyPayment) }}</span>
          <span><?php echo esc_html($settings['currency_symbol']); ?></span>
        </div>
      </div>
    </div>

    <div class="summary-card">
      <h2><?php _e('Send a request', 'loan-calculator'); ?></h2>

      <div class="input-group">
        <div class="label-with-bonus">
          <label>
            <?php _e('Full Name', 'loan-calculator'); ?>
            <span class="required">*</span>
          </label>
        </div>
        <input
          type="text"
          v-model="fullName"
          @input="capitalizeWords"
          placeholder="<?php esc_attr_e('Enter full name', 'loan-calculator'); ?>"
          class="form-input">
        <div class="error-text" v-if="showRequired && !isValidFullName">
          <?php _e('Full name must contain', 'loan-calculator'); ?> <?php echo esc_html($settings['required_name_words']);
                                                                    echo "&nbsp;";
                                                                    _e('words', 'loan-calculator'); ?>
        </div>
      </div>

      <div class="input-group">
        <div class="label-with-bonus">
          <label>
            <?php _e('Mobile Phone', 'loan-calculator'); ?>
            <span class="required">*</span>
          </label>
        </div>
        <div class="phone-input-wrapper">
          <span class="phone-prefix"><?php echo esc_html($settings['phone_mask'] ? substr($settings['phone_mask'], 0, strpos($settings['phone_mask'], '(')) : '+7'); ?></span>
          <input
            type="tel"
            v-model="phone"
            @input="formatPhone"
            @focus="initializePhone"
            @click="handlePhoneClick"
            placeholder="<?php echo esc_attr(str_replace('#', '_', substr($settings['phone_mask'], strpos($settings['phone_mask'], '(')))); ?>"
            class="form-input phone-input">
        </div>
        <div class="error-text" v-if="showRequired && !isValidPhone">
          <?php _e('Please enter a valid phone number', 'loan-calculator'); ?>
        </div>
      </div>

      <div class="terms">
        <span><?php _e('By filling out the form, I accept the', 'loan-calculator'); ?> </span>
        <a target="_blank" href="<?php echo esc_url($settings['terms_link']); ?>" class="link">
          <?php _e('terms of information transfer', 'loan-calculator'); ?>
        </a>
        <span> <?php _e('and give', 'loan-calculator'); ?> </span>
        <a target="_blank" href="<?php echo esc_url($settings['products_link']); ?>" class="link">
          <?php _e('consent to receive information about Bank and partner products and services', 'loan-calculator'); ?>
        </a>
      </div>

      <button class="submit-button" @click="submitForm" :disabled="isLoading" v-if="!isSubmitted">
        <span v-if="!isLoading"><?php _e('Submit', 'loan-calculator'); ?></span>
        <span v-else class="loader"></span>
      </button>
      <p v-else class="success-message"><?php esc_html_e('Application submitted successfully, we will contact you shortly!', 'loan-calculator'); ?></p>

    </div>
  </div>
</div>
