<?php

function register_loan_application_meta()
{
  $meta_fields = [
    '_phone' => [
      'type' => 'string',
      'single' => true,
      'show_in_rest' => true,
    ],
    '_full_name' => [
      'type' => 'string',
      'single' => true,
      'show_in_rest' => true,
    ],
    '_amount' => [
      'type' => 'number',
      'single' => true,
      'show_in_rest' => true,
    ],
    '_term' => [
      'type' => 'number',
      'single' => true,
      'show_in_rest' => true,
    ],
    '_status' => [
      'type' => 'string',
      'single' => true,
      'show_in_rest' => true,
      'default' => 'new',
    ],
    '_monthly_payment' => [
      'type' => 'string',
      'single' => true,
      'show_in_rest' => true,
    ],
  ];

  foreach ($meta_fields as $meta_key => $args) {
    $args['auth_callback'] = function () {
      return current_user_can('edit_posts');
    };
    register_post_meta('loan_application', $meta_key, $args);
  }
}

function render_loan_application_meta_box($post)
{
  $phone = get_post_meta($post->ID, '_phone', true);
  $full_name = get_post_meta($post->ID, '_full_name', true);
  $amount = get_post_meta($post->ID, '_amount', true);
  $term = get_post_meta($post->ID, '_term', true);
  $status = get_post_meta($post->ID, '_status', true);
  $monthly_payment = get_post_meta($post->ID, '_monthly_payment', true);

  // Получаем настройки калькулятора
  $settings = get_option('loan_calculator_settings', []);
  $currency_symbol = isset($settings['currency_symbol']) ? $settings['currency_symbol'] : '₽';
?>
  <style>
    .loan-details-table {
      width: 100%;
    }

    .loan-details-table td {
      padding: 5px;
    }

    .loan-details-table tr td:first-child {
      font-weight: bold;
      width: 200px;
    }
  </style>
  <table class="loan-details-table">
    <tr>
      <td><?php _e('Full Name:', 'loan-calculator'); ?></td>
      <td><?php echo esc_html($full_name); ?></td>
    </tr>
    <tr>
      <td><?php _e('Phone:', 'loan-calculator'); ?></td>
      <td><?php echo esc_html($phone); ?></td>
    </tr>
    <tr>
      <td><?php _e('Loan Amount:', 'loan-calculator'); ?></td>
      <td><?php echo number_format($amount, 0, ',', ' '); ?> <?php echo esc_html($currency_symbol); ?></td>
    </tr>
    <tr>
      <td><?php _e('Loan Term:', 'loan-calculator'); ?></td>
      <td><?php echo esc_html($term); ?> <?php _e('years', 'loan-calculator'); ?></td>
    </tr>
    <tr>
      <td><?php _e('Monthly Payment:', 'loan-calculator'); ?></td>
      <td><?php echo number_format($monthly_payment, 0, ',', ' '); ?> <?php echo esc_html($currency_symbol); ?></td>
    </tr>
    <tr>
      <td><?php _e('Application Status:', 'loan-calculator'); ?></td>
      <td>
        <select name="loan_status">
          <option value="new" <?php selected($status, 'new'); ?>><?php _e('New', 'loan-calculator'); ?></option>
          <option value="processing" <?php selected($status, 'processing'); ?>><?php _e('Processing', 'loan-calculator'); ?></option>
          <option value="approved" <?php selected($status, 'approved'); ?>><?php _e('Approved', 'loan-calculator'); ?></option>
          <option value="rejected" <?php selected($status, 'rejected'); ?>><?php _e('Rejected', 'loan-calculator'); ?></option>
        </select>
      </td>
    </tr>
  </table>
<?php
}
